@@ -6,4 +6,5 @@
 #'
 #' @format A character vector with 665 rows.\cr 
 #' 
-"stopwords"
\ No newline at end of file
+#' @name stopwords
+NULL
\ No newline at end of file
